VideoEvent class

Event emitted from the platform implementation.

Annotations

Constructors

VideoEvent({required VideoEventType eventType, DurationRange? duration, Size? size, int? buffered, String? text, bool? isPlaying})
Creates an instance of VideoEvent.

Properties

buffered → int?
Buffered size of the video.
final
duration → DurationRange?
Duration of the video.
final
eventType → VideoEventType
The type of the event.
final
hashCode → int
The hash code for this object.
no setteroverride
isPlaying → bool?
Whether the video is currently playing.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size?
Size of the video.
final
text → String?
Subtitle text of the video.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override