create method
Creates an instance of a video player and returns its playerId.
For two-phase initialization, this method only creates the player without starting playback preparation. Call prepare() separately after setting up event listeners.
Implementation
Future<int?> create(DataSource dataSource) {
throw UnimplementedError('create() has not been implemented.');
}